// Copyright (C) 2020 The Qt Company.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only

#ifndef QTVIRTUALKEYBOARDGLOBAL_H
#define QTVIRTUALKEYBOARDGLOBAL_H

#include <QtVirtualKeyboard/qvirtualkeyboard_global.h>
#include <QtVirtualKeyboard/private/qtvirtualkeyboard-config_p.h>

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//


#endif // QTVIRTUALKEYBOARDGLOBAL_H

