// Copyright (C) 2018 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only

#ifndef QVIRTUALKEYBOARD_GLOBAL_H
#define QVIRTUALKEYBOARD_GLOBAL_H

#include <QtCore/qglobal.h>
#include <QtVirtualKeyboard/qtvirtualkeyboard-config.h>
#include <QtVirtualKeyboard/qtvirtualkeyboardexports.h>

#endif
